@@ -16,7 +16,7 @@ test_that("galah_config creates nested folders where requested", {
 })
 
 test_that("galah_config checks download_id", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   galah_config(verbose = TRUE)
   expect_error(galah_config(download_reason_id = 17))
   expect_error(galah_config(download_reason_id = "NOTHING"))
@@ -27,7 +27,7 @@ test_that("galah_config checks download_id", {
 })
 
 test_that("galah_config checks inputs", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   expect_error(galah_config(caching = "value"))
   expect_error(galah_config(verbose = "value"))
   expect_error(galah_config(email = 4))
@@ -50,4 +50,4 @@ test_that("galah_config can swap between atlases", {
                     acronym = "GBIF",
                     region = "Global"))
   galah_config(atlas = "ALA")
-})
\ No newline at end of file
+})
