@@ -6,7 +6,7 @@ test_that("swapping to atlas = Austria works", {
 })
 
 test_that("show_all(assertions) works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- show_all(assertions) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -17,7 +17,7 @@ test_that("show_all(assertions) works for Austria", {
 })
 
 test_that("show_all(collections) works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- show_all(collections) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -28,7 +28,7 @@ test_that("show_all(collections) works for Austria", {
 })
 
 test_that("show_all(datasets) works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- show_all(datasets) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -39,7 +39,7 @@ test_that("show_all(datasets) works for Austria", {
 })
 
 test_that("show_all(fields) works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- show_all(fields) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -50,7 +50,7 @@ test_that("show_all(fields) works for Austria", {
 })
 
 test_that("show_all(licences) works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- show_all(licences) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -62,7 +62,7 @@ test_that("show_all(licences) works for Austria", {
 })
 
 test_that("show_all(lists) works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- show_all(lists) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -73,7 +73,7 @@ test_that("show_all(lists) works for Austria", {
 })
 
 test_that("show_all(providers) works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- show_all(providers) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -84,7 +84,7 @@ test_that("show_all(providers) works for Austria", {
 })
 
 test_that("show_all(reasons) works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- show_all(reasons) |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -99,7 +99,7 @@ test_that("show_all(profiles) fails for Austria", {
 })
 
 test_that("search_all(fields) works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- search_all(fields, "year") |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -108,7 +108,7 @@ test_that("search_all(fields) works for Austria", {
 })
 
 test_that("search_all(taxa) works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- search_all(taxa, "Vulpes vulpes") |>
     try(silent = TRUE)
   skip_if(inherits(x, "try-error"), message = "API not available")
@@ -117,7 +117,7 @@ test_that("search_all(taxa) works for Austria", {
 })
 
 test_that("show_values works for fields for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- try({search_all(fields, "basis_of_record") |> 
     show_values()},
     silent = TRUE)
@@ -127,7 +127,7 @@ test_that("show_values works for fields for Austria", {
 })
 
 test_that("show_values works for lists for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- try({search_all(lists, "dr30") |> 
     show_values()},
     silent = TRUE)
@@ -137,7 +137,7 @@ test_that("show_values works for lists for Austria", {
 })
 
 test_that("atlas_counts works with type = 'occurrences' for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- atlas_counts() |>
     pull(count) |>
     try(silent = TRUE)
@@ -146,7 +146,7 @@ test_that("atlas_counts works with type = 'occurrences' for Austria", {
 })
 
 test_that("atlas_counts works with type = 'species' for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   x <- atlas_counts(type = "species") |>
     pull(count) |>
     try(silent = TRUE)
@@ -156,7 +156,7 @@ test_that("atlas_counts works with type = 'species' for Austria", {
 
 ## FIXME: Only works when run_checks = TRUE
 test_that("atlas_counts works with galah_identify for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   result <- galah_call() |>
     galah_identify("Mammalia") |> # run_checks = TRUE works
     atlas_counts() |>
@@ -172,7 +172,7 @@ test_that("atlas_counts works with galah_identify for Austria", {
 })
 
 test_that("atlas_counts works with group_by for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   result <- galah_call() |>
     galah_filter(year >= 2020) |>
     galah_group_by(year) |>
@@ -184,7 +184,7 @@ test_that("atlas_counts works with group_by for Austria", {
 })
 
 test_that("atlas_species works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   galah_config(
     atlas = "Austria",
     email = "ala4r@ala.org.au", 
@@ -203,7 +203,7 @@ test_that("atlas_species works for Austria", {
 
 ## FIXME: Test only works when run_checks = TRUE
 test_that("atlas_occurrences works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   galah_config(
     atlas = "Austria",
     email = "ala4r@ala.org.au", 
@@ -240,7 +240,7 @@ test_that("atlas_occurrences works for Austria", {
 })
 
 test_that("atlas_media() works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   galah_config(
     atlas = "Austria",
     email = "ala4r@ala.org.au",
@@ -272,7 +272,7 @@ test_that("atlas_media() works for Austria", {
 
 ## FIXME: atlas_taxonomy doesn't work
 test_that("atlas_taxonomy works for Austria", {
-  skip_if_offline()
+  skip_if_offline(); skip_on_ci()
   y <- galah_call() |>
     identify("Aves") |>
     filter(rank >= order) |>
